pub struct Completion {
pub completion: String,
pub display: Option<String>,
pub suffix: Suffix,
}Expand description
Represents a single possible completion
Fields
completion: StringWhole completion text
display: Option<String>Listing display string; None if matches completion
suffix: SuffixCompletion suffix; replaces append character
Implementations
Sourceimpl Completion
impl Completion
Sourcepub fn simple(s: String) -> Completion
pub fn simple(s: String) -> Completion
Returns a simple Completion value, with display string matching
completion and using the default completion suffix.
Sourcepub fn completion(&self, def_suffix: Option<char>) -> Cow<'_, str>
pub fn completion(&self, def_suffix: Option<char>) -> Cow<'_, str>
Returns the full completion string, including suffix, using the given default suffix if one is not assigned to this completion.
Sourcepub fn display_chars(&self) -> usize
pub fn display_chars(&self) -> usize
Returns the number of characters displayed