Module reader

Module reader 

Provides access to terminal read operations

Structs

BindingIter
Iterator over Reader bindings
Reader
Provides access to data related to reading and processing user input.

Enums

ReadResult
Returned from read_line to indicate user input

Constants

END_INVISIBLE
Indicates the end of a series of invisible characters in the prompt
START_INVISIBLE
Indicates the start of a series of invisible characters in the prompt
STRING_CHARS
Default set of string characters
WORD_BREAK_CHARS
Default set of word break characters